(*
 * The LOOP Project
 *
 * The LOOP Team, Dresden University and Nijmegen University
 *
 * Copyright (C) 2002
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License in file COPYING in this or one of the
 * parent directories for more details.
 *
 * Created 14.5.99 by Hendrik
 *
 * Time-stamp: <Tuesday 16 July 02 22:24:21 tews@ithif56.inf.tu-dresden.de>
 *
 * theory for theorems
 *
 * $Id: class_theorems_theory.mli,v 1.3 2002/07/18 13:43:21 tews Exp $
 *
 *)


open Classtypes

class ccsl_isar_start_theorems
  : ccsl_iface_type -> ccsl_sig_theory_type

class ccsl_isar_close_theorems
  : ccsl_iface_type -> ccsl_sig_theory_type

class ccsl_class_theorem_theory
  : ccsl_iface_type ->  ccsl_class_theory_type 



(*** Local Variables: ***)
(*** version-control: t ***)
(*** kept-new-versions: 5 ***)
(*** delete-old-versions: t ***)
(*** time-stamp-line-limit: 30 ***)
(*** End: ***)

